@@ -76,6 +76,9 @@ void print_error_page(char* file_name, int line_number, char* message)
                 file_name,
                 line_number,
                 message);
+    o(      "<div>\n"
+            "   if you are setting up Starbug1 now, <a href=\"%s/../env-check.html\">check environment.</a>\n"
+            "</div>\n", cgiScriptName);
     o(      "<hr />"
             "<div align=\"right\">"
             "<address>%s.</address>"
@@ -822,7 +825,6 @@ void set_locale(char* locale)
 {
     char locale_utf8[DEFAULT_LENGTH];
     sprintf(locale_utf8, "%s.UTF-8", locale);
-    d("locale: %s\n", locale_utf8);
 #ifndef _WIN32
     setenv("LANG", locale_utf8, 1); /* FreeBSD(さくらインターネット)でsetlocaleが動作しない場合があったため、環境変数を書き換える。 */
 #else
@@ -833,12 +835,29 @@ void set_locale(char* locale)
         putenv(envstr);
     }
 #endif
-    d("setlocale: %s\n", setlocale(LC_ALL, locale_utf8));
-    d("bindtextdomain: %s\n", bindtextdomain("starbug1", "locale"));
-    d("textdomain: %s\n", textdomain("starbug1"));
+    setlocale(LC_ALL, locale_utf8);
+    bindtextdomain("starbug1", "locale");
+    textdomain("starbug1");
 #ifdef _WIN32
     bind_textdomain_codeset("starbug1", "utf-8");
 #endif
 }
 
+#ifdef _WIN32
+struct tm* localtime_r(const time_t *timer, struct tm *result)
+{
+    struct tm *r = localtime (timer);
+    if (r == NULL || result == NULL)
+        return NULL; 
+    memcpy(result, r, sizeof(result));
+    return result;
+}
+#endif
+
+double get_microseconds()
+{
+    struct timeval t;
+    gettimeofday(&t, NULL);
+    return t.tv_sec + t.tv_usec * 1e-6;
+}
 /* vim: set ts=4 sw=4 sts=4 expandtab fenc=utf-8: */
