@@ -90,6 +90,7 @@ char* get_ext(char*);
 void page_not_found();
 #define MIN(a,b) (((a)<(b))?(a):(b)) 
 #define MAX(a,b) (((a)>(b))?(a):(b))
+double get_microseconds();
 
 extern char g_project_code[DEFAULT_LENGTH];
 extern char g_project_code_4_url[DEFAULT_LENGTH];
@@ -98,5 +99,9 @@ extern char g_path_info[DEFAULT_LENGTH];
 void cgi_escape(char*);
 void print_field_help();
 void set_locale(char*);
+#ifdef _WIN32
+struct tm* localtime_r(const time_t* timer, struct tm* result);
+#define mkstemp(p) mktemp(p)
+#endif
 #endif
 /* vim: set ts=4 sw=4 sts=4 expandtab fenc=utf-8: */
